pilas.depurador.Depurador

Package pilas :: Module depurador :: Class Depurador |
[hide private]
[frames] | no frames]

# Class Depurador

source code

                object --+
                         |
    DepuradorDeshabilitado --+
                             |
                            Depurador

Esta clase permite hacer depuraciones visuales.

La depuracion visual en pilas consiste en poder mostrar informacion que generalmente es invisible a los jugadores. Por ejemplo, donde estan situados los puntos de control, los radios de colision etc.

Esta clase administra varios modos depuracion, que son los que dibujan figuras geometricas.

Instance Methods | [hide private]
__init__(self, lienzo, fps) x.__init__(...) initializes x; see help(type(x)) for signature | source code
comienza_dibujado(self, motor, painter) | source code
dibuja_al_actor(self, motor, painter, actor) | source code
termina_dibujado(self, motor, painter) | source code
cuando_pulsa_tecla(self, codigo_tecla, texto_tecla) | source code
cuando_mueve_el_mouse(self, x, y) | source code
_cambiar_grosor_de_bordes(self, cambio) | source code
_alternar_modo(self, clase_del_modo) | source code
_activar_modo(self, clase_del_modo) | source code
_desactivar_modo(self, clase_del_modo) | source code
_mostrar_nombres_de_modos(self, painter) | source code
_mostrar_posicion_del_mouse(self, painter) | source code
_mostrar_cuadros_por_segundo(self, painter) | source code
_mostrar_cantidad_de_actores(self, painter) | source code
definir_modos(self, fisica=False, info=False, puntos_de_control=False, radios=False, areas=False, posiciones=False, log=False) Permite habilitar o deshabilitar los modos depuración. | source code
_desactivar_todos_los_modos(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, lienzo, fps) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### comienza_dibujado(self, motor, painter) | source code
Overrides: DepuradorDeshabilitado.comienza_dibujado

### dibuja_al_actor(self, motor, painter, actor) | source code
Overrides: DepuradorDeshabilitado.dibuja_al_actor

### termina_dibujado(self, motor, painter) | source code
Overrides: DepuradorDeshabilitado.termina_dibujado

### cuando_pulsa_tecla(self, codigo_tecla, texto_tecla) | source code
Overrides: DepuradorDeshabilitado.cuando_pulsa_tecla

### cuando_mueve_el_mouse(self, x, y) | source code
Overrides: DepuradorDeshabilitado.cuando_mueve_el_mouse

### definir_modos(self, fisica=False, info=False, puntos_de_control=False, radios=False, areas=False, posiciones=False, log=False) | source code
Permite habilitar o deshabilitar los modos depuración. Cada uno de los argumentos representa un modo depuración, el valor True habilita el modo, False lo deshabilita.